# Analysis of the Sea Surface Temperature

In this example we analyse the NOAA OI SST V2 High Resolution Dataset of the sea surface temperature.

Steps:
1. Write a scritpt to download data from [https://psl.noaa.gov/data/gridded/data.noaa.oisst.v2.highres.html](https://psl.noaa.gov/data/gridded/data.noaa.oisst.v2.highres.html), and specifically the Daily Data from [https://downloads.psl.noaa.gov/Datasets/noaa.oisst.v2.highres](https://downloads.psl.noaa.gov/Datasets/noaa.oisst.v2.highres). For example we might be interested in the weekly mean.
2. Start by running linear and kernel regression, and analysing modes with `dymodx`.
